@@ -53,7 +53,7 @@ class Client(BaseApi):
         return Auction(self.token, self.base_url, item_id, region)
 
     def __repr__(self):
-        return f"<Client> api_link='{self.base_url}' token='{self.part_of_token}'"
+        return f"<Client> base_url='{self.base_url}' token='{self.part_of_token}'"
 
 
 class AppClient(Client):
@@ -71,7 +71,7 @@ class AppClient(Client):
         return AppClan(self.token, self.base_url, clan_id, region)
 
     def __repr__(self):
-        return f"<AppClient> api_link='{self.base_url}' token='{self.part_of_token}'"
+        return f"<AppClient> base_url='{self.base_url}' token='{self.part_of_token}'"
 
 
 class UserClient(Client):
@@ -113,4 +113,4 @@ class UserClient(Client):
         return UserClan(self.token, self.base_url, clan_id, region)
 
     def __repr__(self):
-        return f"<UserClient> api_link='{self.base_url}' token='{self.part_of_token}'"
+        return f"<UserClient> base_url='{self.base_url}' token='{self.part_of_token}'"
